# RPCLayout

![](https://cdn.discordapp.com/attachments/954499110763892807/955216312999739433/gato-digitando.gif)

A simple way to make a Discord rich presence with API using JSON parser to make it.
Includes a multiple functions to help in the development with apis json

# Installation
Simple as possible use:
```sh
python -m pip install RPCLayout
```
or clone code and use at module.

# Version 2.0.0
Bugs fixed, import fixed for MacOS

# Version 2.0.1
+ Added:
    - __test__ class for test functions.
    - _system() - Return the operating system
    - _getpid() - Return the actual PID of the program
    - destroy() - Destroy the actual process and RPC.
    - Added more HTTP Responses Error for request_api() function

# Repositories Used
[pypresence](https://github.com/qwertyquerty/pypresence)
[RotMGRPC](https://github.com/neopkr/RotMGRPC)

## Requires:
pip install requests
